'use strict';

const consoleLogger = require('ci-logger');

const testResultSymbols = Object.freeze({
    passed: ' √',
    failed: ' ×',
    warning: ' ‼'
});

// eslint-disable-next-line max-lines-per-function
module.exports = () => {
    const testResults = {
        executionStart: new Date(),
        summary: {
            tests: 0,
            passed: 0,
            warning: 0,
            failed: 0
        },
        results: []
    };

    let currentUrlTests;
    const startUrlTests = (url) => {
        const urlTestResults = {
            url,
            tests: []
        };
        testResults.results.push(urlTestResults);
        currentUrlTests = urlTestResults;
        consoleLogger.log({ message: `\nTesting URL: ${url}` });
    };

    const logTestResults = (testResult) => {
        if (testResult) {
            currentUrlTests.tests.push(testResult);
            testResults.summary.tests++;
            testResults.summary[testResult.result]++;

            consoleLogger.log({
                message: `${testResult.name} (${testResult.result})`,
                isResult: true,
                resultPrefix: testResultSymbols[testResult.result]
            });
        }
    };

    const outputTestSummary = () => {
        consoleLogger.log({ message: `\n Tests: ${testResults.summary.tests}\n Passed: ${testResults.summary.passed}\n Warning: ${testResults.summary.warning}\n Failed: ${testResults.summary.failed}\n` });
    };

    const getTestResults = () => {
        outputTestSummary();
        return testResults;
    };

    return {
        startUrlTests,
        logTestResults,
        getTestResults
    };
};
