'use strict';

const fs = require('fs');
const path = require('path');
const handlebars = require('handlebars');

const htmlReportTemplateName = 'report-template.handlebars';
const htmlReportFileName = './pagean-results.html';
const jsonReportFileName = './pagean-results.json';

handlebars.registerHelper('json', (context) => {
    // eslint-disable-next-line no-magic-numbers
    return JSON.stringify(context, undefined, 2);
});

const saveHtmlReport = (results) => {
    const templateFile = path.resolve(path.join(__dirname, htmlReportTemplateName));
    const htmlReportTemplate = fs.readFileSync(templateFile, 'utf-8');
    const template = handlebars.compile(htmlReportTemplate);
    const htmlReport = template(results);
    fs.writeFileSync(htmlReportFileName, htmlReport);
};

const saveJsonReport = (results) => {
    fs.writeFileSync(jsonReportFileName, JSON.stringify(results));
};

const saveReports = (results) => {
    saveJsonReport(results);
    saveHtmlReport(results);
};

module.exports.saveReports = saveReports;
