'use strict';

const fs = require('fs');
const path = require('path');

const reporter = require('../lib/reporter');

const htmlReportFileName = './pagean-results.html';
const jsonReportRawFileName = 'pagean-results.json';
const jsonReportFileName = `./${jsonReportRawFileName}`;

// eslint-disable-next-line max-lines-per-function
describe('reporter', () => {
    const saveReportTest = (fileName) => {
        const testResults = {};
        const writeFileSpy = jest.spyOn(fs, 'writeFileSync').mockImplementation(() => {});

        reporter.saveReports(testResults);

        expect(writeFileSpy).toHaveBeenCalledWith(fileName, expect.any(String));
        return writeFileSpy.mock.calls[0][1];
    };

    afterEach(() => {
        jest.restoreAllMocks();
    });

    it('should save HTML report file', () => {
        expect.assertions(1);
        saveReportTest(htmlReportFileName);
    });

    it('should save JSON report file', () => {
        expect.assertions(1);
        saveReportTest(jsonReportFileName);
    });

    it('should save JSON report with valid JSON', () => {
        expect.assertions(2); // eslint-disable-line no-magic-numbers
        const reportContents = saveReportTest(jsonReportFileName);
        expect(() => JSON.parse(reportContents)).not.toThrow();
    });

    it('should write expected JSON and HTML reports', () => {
        expect.assertions(3); // eslint-disable-line no-magic-numbers
        const reportCount = 2;
        const jsonReportFile = path.join('tests', 'test-cases', jsonReportRawFileName);
        const testResults = JSON.parse(fs.readFileSync(jsonReportFile, 'utf-8'));
        const writeFileSpy = jest.spyOn(fs, 'writeFileSync').mockImplementation(() => {});

        reporter.saveReports(testResults);

        expect(writeFileSpy).toHaveBeenCalledTimes(reportCount);
        // eslint-disable-next-line prefer-destructuring -- less intuitive
        const jsonReport = writeFileSpy.mock.calls[0][1];
        expect(jsonReport).toMatchSnapshot();

        // eslint-disable-next-line prefer-destructuring -- less intuitive
        const htmlReport = writeFileSpy.mock.calls[1][1];
        expect(htmlReport).toMatchSnapshot();
    });
});
